#
# spec file for package kf6-kio
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define qt6_version 6.7.0

%define rname kio
# Full KF6 version (e.g. 6.9.0)
%{!?_kf6_version: %global _kf6_version %{version}}
# Last major and minor KF6 version (e.g. 6.0)
%{!?_kf6_bugfix_version: %define _kf6_bugfix_version %(echo %{_kf6_version} | awk -F. '{print $1"."$2}')}
%bcond_without released
Name:           kf6-kio
Version:        6.11.0
Release:        1.2
Summary:        Network transparent access to files and data
License:        LGPL-2.1-or-later
URL:            https://www.kde.org
Source:         %{rname}-%{version}.tar.xz
%if %{with released}
Source1:        %{rname}-%{version}.tar.xz.sig
Source2:        frameworks.keyring
%endif
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  kf6-extra-cmake-modules >= %{_kf6_bugfix_version}
BuildRequires:  libattr-devel
BuildRequires:  pkgconfig
BuildRequires:  qt6-gui-private-devel >= %{qt6_version}
BuildRequires:  cmake(KF6Archive) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6Auth) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6Bookmarks) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6ColorScheme) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6Completion) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6Config) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6ConfigWidgets) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6CoreAddons) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6Crash) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6DBusAddons) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6DocTools) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6GuiAddons) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6I18n) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6IconThemes) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6ItemViews) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6JobWidgets) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6KDED) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6Service) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6Solid) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6TextWidgets) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6Wallet) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6WidgetsAddons) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6WindowSystem) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(Qt6Concurrent) >= %{qt6_version}
BuildRequires:  cmake(Qt6Core) >= %{qt6_version}
BuildRequires:  cmake(Qt6Core5Compat) >= %{qt6_version}
BuildRequires:  cmake(Qt6DBus) >= %{qt6_version}
BuildRequires:  cmake(Qt6Network) >= %{qt6_version}
BuildRequires:  cmake(Qt6Test) >= %{qt6_version}
BuildRequires:  cmake(Qt6ToolsTools) >= %{qt6_version}
BuildRequires:  cmake(Qt6UiPlugin) >= %{qt6_version}
BuildRequires:  cmake(Qt6Widgets) >= %{qt6_version}
BuildRequires:  cmake(Qt6Xml) >= %{qt6_version}
BuildRequires:  pkgconfig(libacl)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(libxslt)
BuildRequires:  pkgconfig(mount)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(x11)
Requires:       kf6-kded >= %{_kf6_bugfix_version}
# For discrete GPU discovery
Recommends:     switcheroo-control

%description
This framework implements almost all the file management functions you
will ever need. In fact, the KDE file manager (Dolphin) and the KDE
file dialog also uses this to provide its network-enabled file management.

%package doc
Summary:        HTML documentation for KIO

%description doc
This package contains documentation for the KIO framework.

%package -n libKF6KIO6
Summary:        KIO Libraries
Requires:       kf6-kio >= %{version}

%description -n libKF6KIO6
Network transparent access to files and data

%package devel
Summary:        Network transparent access to files and data
Requires:       libKF6KIO6 = %{version}
Requires:       cmake(KF6Bookmarks) >= %{_kf6_bugfix_version}
Requires:       cmake(KF6Completion) >= %{_kf6_bugfix_version}
Requires:       cmake(KF6Config) >= %{_kf6_bugfix_version}
Requires:       cmake(KF6CoreAddons) >= %{_kf6_bugfix_version}
Requires:       cmake(KF6ItemViews) >= %{_kf6_bugfix_version}
Requires:       cmake(KF6JobWidgets) >= %{_kf6_bugfix_version}
Requires:       cmake(KF6Service) >= %{_kf6_bugfix_version}
Requires:       cmake(KF6Solid) >= %{_kf6_bugfix_version}
Requires:       cmake(KF6WindowSystem) >= %{_kf6_bugfix_version}
Requires:       cmake(KF6XmlGui) >= %{_kf6_bugfix_version}
Requires:       cmake(Qt6Concurrent) >= %{qt6_version}
Requires:       cmake(Qt6DBus) >= %{qt6_version}
Requires:       cmake(Qt6Network) >= %{qt6_version}

%description devel
This framework implements almost all the file management functions you
will ever need. In fact, the KDE file manager (Dolphin) and the KDE
file dialog also uses this to provide its network-enabled file management.
Development files.

%lang_package

%prep
%autosetup -p1 -n %{rname}-%{version}

%build
%ifarch ppc64
%define _lto_cflags %{nil}
%endif

%cmake_kf6 -DBUILD_QCH:BOOL=TRUE

%kf6_build

%install
%kf6_install

%fdupes %{buildroot}

%find_lang kio --with-man --all-name

%ldconfig_scriptlets -n libKF6KIO6

%files
%{_kf6_applicationsdir}/ktelnetservice6.desktop
%{_kf6_applicationsdir}/org.kde.kiod6.desktop
%{_kf6_bindir}/ktelnetservice6
%{_kf6_bindir}/ktrash6
%{_kf6_datadir}/searchproviders/
%{_kf6_debugdir}/kio.categories
%{_kf6_debugdir}/kio.renamecategories
%{_kf6_libdir}/libkuriikwsfiltereng_private.so
%{_kf6_libexecdir}/kiod6
%{_kf6_libexecdir}/kioexec
%{_kf6_libexecdir}/kioworker
%{_kf6_plugindir}/designer/kio6widgets.so
%{_kf6_plugindir}/kf6/kded/remotenotifier.so
%{_kf6_plugindir}/kf6/kio/kio_file.so
%{_kf6_plugindir}/kf6/kio/kio_ftp.so
%{_kf6_plugindir}/kf6/kio/kio_ghelp.so
%{_kf6_plugindir}/kf6/kio/kio_help.so
%{_kf6_plugindir}/kf6/kio/kio_http.so
%{_kf6_plugindir}/kf6/kio/kio_remote.so
%{_kf6_plugindir}/kf6/kio/kio_trash.so
%dir %{_kf6_plugindir}/kf6/kiod
%{_kf6_plugindir}/kf6/kiod/kioexecd.so
%{_kf6_plugindir}/kf6/kiod/kpasswdserver.so
%{_kf6_plugindir}/kf6/kiod/kssld.so
%dir %{_kf6_plugindir}/kf6/kio_dnd
%{_kf6_plugindir}/kf6/kio_dnd/dropintonewfolder.so
%{_kf6_plugindir}/kf6/urifilters/
%{_kf6_sharedir}/dbus-1/services/org.kde.kiod6.service
%{_kf6_sharedir}/dbus-1/services/org.kde.kioexecd6.service
%{_kf6_sharedir}/dbus-1/services/org.kde.kpasswdserver6.service
%{_kf6_sharedir}/dbus-1/services/org.kde.kssld6.service

%files doc
%{_kf6_htmldir}/*

%files -n libKF6KIO6
%license LICENSES/*
%doc README.md
%{_kf6_libdir}/libKF6KIOCore.so.*
%{_kf6_libdir}/libKF6KIOFileWidgets.so.*
%{_kf6_libdir}/libKF6KIOGui.so.*
%{_kf6_libdir}/libKF6KIOWidgets.so.*

%files devel
%doc %{_kf6_qchdir}/KF6KIO.*
%{_kf6_cmakedir}/KF6KIO/
%{_kf6_includedir}/KIO/
%{_kf6_includedir}/KIOCore/
%{_kf6_includedir}/KIOFileWidgets/
%{_kf6_includedir}/KIOGui/
%{_kf6_includedir}/KIOWidgets/
%{_kf6_libdir}/libKF6KIOCore.so
%{_kf6_libdir}/libKF6KIOFileWidgets.so
%{_kf6_libdir}/libKF6KIOGui.so
%{_kf6_libdir}/libKF6KIOWidgets.so
%{_kf6_sharedir}/kdevappwizard/templates/kioworker6.tar.bz2

%files lang -f kio.lang

%changelog
* Sat Feb  8 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.11.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.11.0
- Too many changes since 6.10.0, only listing bugfixes:
  * A way to insert KUrlNavigator pieces in a deterministic place in the focus chain (kde#409540)
  * Fix symlink path resolution in File Properties (kde#476808)
  * kmountpoint: Handle device IDs for bind mounts (kde#494129)
  * kfileplacesview: when adding new places item, let it figure out the icon (kde#498580)
  * Default to creating new places items globally (kde#498579)
  * dropjob: Check if file is already in trash during dropjob (kde#497390)
  * trash: prevent an assert when trash cache is missing (kde#497268)
* Thu Jan  9 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.10.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.10.0
- Changes since 6.9.0:
  * [kfilefiltercombo] Fix 'All supported files' for more than 3 filters
  * Update dependency version to 6.10.0
  * Remove unimplemented methods
  * [kfilefiltercombo] Fix creating 'All supported types' filter
  * StandardThumbnailJob is internal, header not installed
  * Update version to 6.10.0
* Sun Dec  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.9.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.9.0
- Changes since 6.8.0:
  * Update dependency version to 6.9.0
  * adapt test to new error code
  * [ftp] Give better error message when creating files is not allowed
  * file_unix: check chown return when setting owner
  * CommandLauncherJob: fail when launch an non-existing executable
  * don't static cast qobjects
  * kpropertiesdialog: fix user display to actually use the user data (kde#496745)
  * Add autotest for parsing bug and actually report error status
  * Fix out of bounds for KRunMX1::expandEscapedMacro (kde#495606)
  * kcoredirlister: Remove iterator assert, use if instead (kde#493319)
  * Haiku support: Disable SHM, link to libnetwork, further fixes
  * It compiles fine without deprecated methods
  * KDirOperator: improve handling of forward/back mouse buttons
  * KUrlNavigator: Fix Tab order
  * Haiku build fixes
  * [previewjob] Assert that path is absolute
  * Deprecate http_update_cache
  * KUrlNavigatorDropDownButton: Add text and tooltip
  * Update version to 6.9.0
* Mon Nov  4 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.8.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.8.0
- Too many changes since 6.7.0, only listing bugfixes:
  * http worker: handle dav[s] protocol (kde#365356)
  * KNewFileMenu: Prevent using home directory as template directory (kde#494679)
  * Preview: better clean after standard thumbnailer (kde#493274)
  * openurljob.cpp: Avoid opening files in endless loop if mimetype is set to open with xdg-open (kde#494335)
  * [KFilePlacesView] Improve automatic resize heuristic (kde#449544)
  * Clean up Properties dialog to follow HIG, improve UX, remove frames and fix padding regression (kde#484789)
* Mon Oct  7 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.7.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.7.0
- Changes since 6.6.0:
  * Update dependency version to 6.7.0
  * [OpenFileManagerWindowJob] Fix crash when falling back to KRunStrategy (kde#486494)
  * previewjob: Use .cache as temp folder, delete temp file after use (kde#494096)
  * KFileItemActions: Try reading X-KDE-Show-In-Submenu as bool instead of string
  * KFilePlacesView: have setUrl() handle trailing slashes in place URLs
  * KFilePlacesItem: Use Solid to find home mount point
  * fileitem,file_unix: simplify types for stat
  * Remove one level of three nesting in kdevtemplate
  * knewfilemenutest: cleanup
  * knewfilemenutest: test files and folders in ~/Templates
  * ConnectionBackenp: fix passing errorString
  * knewfilemenu: Make ~/Templates work by simply placing files and folders there (kde#191632)
  * KFilePlacesItem: Cache groupType
  * previewjob: avoid calling mkdir for path with two slashs
  * Update version to 6.7.0
* Sat Sep  7 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.6.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.6.0
- Too many changes since 6.5.0, only listing bugfixes:
  * [trash] Fix restoring entries with absolute paths in disk-local trash (kde#463751)
  * Accept service menus that use ServiceTypes to specify their types (kde#478030)
  * Ignore application/x-kde-onlyReplaceEmpty in paste dialog (kde#492006)
  * Correctly escape unit names (kde#488854)
  * gui/kprocessrunner: normalize working directory (kde#490966)
  * Don't show "Move" item in drop menu for source files accessed using http (kde#389600)
* Mon Aug  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.5.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.5.0
- Too many changes since 6.4.0, only listing bugfixes:
  * kfileitem: show relative path for rel symlink (kde#456198)
  * KFilePlacesView: Show label in tooltip if it is elided (kde#454436)
  * Remove parent for DropMenu (kde#490183)
- Drop patch, merged upstream:
  * 0001-Remove-parent-for-DropMenu.patch
* Wed Jul 17 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Add patch to fix issues with dropping files
  (kde#490183, boo#1228053):
  * 0001-Remove-parent-for-DropMenu.patch
* Tue Jul  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.4.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.4.0
- Changes since 6.3.0:
  * core: use QString to format number
  * Remove unnecessary space character in empty text file template (kde#487768)
  * Port DropJob to KJobWidgets::windowHandle()
  * Use resolved executable in KProcessRunner::fromExecutable
  * Handle using parent environment correctly in SystemdProcessRunner
  * Prepare environment for systemd in SystemdProcessRunner
  * Enable CommandLauncherJob tests (modulo _KDE_APPLICATIONS_AS_SERVICE on CI)
  * kmountpoint: use advised call params when possible for libmount
  * Remove unused includes
  * Drop unused modifiers support from user agent code
  * [kprotocolmanager] Remmove unused http_config
  * Remove unused includes
  * Don't pass proxy config to workers
  * Drop protocol proxying
  * Deprecate KProtocolInfo::proxiedBy
  * [ftp] Drop ProxiedBy=http
  * kfileitem.cpp: If fileMode is not unknown, set InitCalled to true in readUDSEntry (kde#485771)
  * support USE_DBUS option to enable/disable dbus use
  * [webdav] emit ERR_UNSUPPORTED_ACTION when performing fileSystemFreeSpace on a file
  * Add desktop file for kiod (kde#459054)
  * gitignore: add VS Code dir
  * kfileitemtest: testBasicDirectory relax size assertion
  * commandlauncherjob: emit error when no executable
* Wed Jun  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.3.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.3.0/
- Changes since 6.2.0:
  * KAbstractFileItemActionPlugin: Remove wrong sentence in documentation
  * don't install header for pure dbus class if no dbus
  * disable dbus not only for android but windows & mac, too
  * Drop errorpage handling from worker
  * [http] Implement resuming at offset again (kde#480506)
  * CI: Require passing tests on Linux and FreeBSD
  * Deprecate KFileWidget::readConfig
  * SSL Info UI file: use notr="true" instead of old comment="KDE::DoNotExtract"
  * kfileitem: cache group names (kde#486956)
  * Move HAVE_STATX cmake test to core (kde#487015)
  * Remove unused includes
  * Properties dialogue URL tab: Fix vertical alignment
  * systemdprocessrunner: change the order launchmodes are returned
  * systemdprocessrunner: change env var names
  * Use ellipsis character instead of three dots in UI strings
* Mon May  6 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.2.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/6.2.0/
- Changes since 6.1.0:
  * [kfilefilter] Consider mime globs valid
  * kfileitemtest: add basic tests for dir
  * file_unix: don't call QMimeDatabase::mimeTypeForFile for directories
  * widgetsaskuseractionhandler prevent crash when job had no parent widget
  * PreviewJob: Add file extension to thumbnail temp files (kde#463989)
  * KFileItem: handle the case parent url path is empty
  * KFileItemActions: Add logic to order actions between separators (kde#466115)
  * KFileItem: fix getStatusBarInfo() displaying symlink target as "http:" (kde#475422)
  * ScopedProcessRunner: support waitForStarted
  * ScopedProcessRunner: fix use of undeclared identifier 'close'
  * [ftp] Always use default timeout values
  * [http] Set error string for ERR_DOES_NOT_EXIST
  * Force test language to en
  * knewfilemenu: Add @since 6.2 to the new signals and methods
  * kfilefilter.h: update API docs
  * kencodingfiledialog dox: rewrite API dox that refer to removed functions
  * kfilewidget dox: replace references to setFilter() with setFilters()
  * Add `EnableRemoteFolderThumbnail` option checking
  * PreviewJob: Display preview for locally mounted remote directories
  * knewfilemenu: add isNewDirNameJobRunning
  * KFilePlacesItem: Show teardown busy indicator during optical media eject
  * KUrlNavigator: allow adding a badge widget after the breadcrumb
  * Set ideal case for TwoVectors
  * udsentry_api_comparison_benchmark: update
  * kurlnavigatorbutton: prevent
  * connection: don't queue tasks until OOM
  * http: Fix parsing DAV:getlastmodified (kde#484671)
  * kfileitem: Linux, use statx to refresh files (kde#446858)
* Fri Apr  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.1.0
  * New feature release
- Too many changes since 6.0.0, only listing bugfixes:
  * Fix authentication prompt not being shown (kde#460944)
  * [kfileplacesmodel] Remove wrong assert (kde#484160)
  * KFileItem: when checking access use current user (kde#483436)
  * Fix webshortcuts not giving searchprovider specific icon (kde#483164)
  * KFileitem: Use internal permissions as best case scenario (kde#477526)
  * connectionbackend: improve jumbo packet handling (kde#481311)
  * Drop legacy keys for m_runOnDiscreteGpuBool (kde#481538)
  * [knewfilemenu] Add window title for new file dialog (kde#482732)
  * fix hide service menu items in context menu (kde#482216)
  * [kterminallauncherjob] Inherit default process environment from parent (kde#482107)
  * [knewfilemenu] Fix error handling when creating a folder that already exists (kde#482145)
- Drop patch, merged upstream:
  * 0001-kterminallauncherjob-Inherit-default-process-environ.patch
* Mon Mar 18 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Add patch to fix KTerminalLaucherJob (kde#482107, boo#1221637):
  * 0001-kterminallauncherjob-Inherit-default-process-environ.patch
* Wed Feb 21 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.0
  * New bugfix release
  * Release announcement not available yet
- Changes since 5.249.0:
  * update version for new release
  * KFilePlacesItem: Strip UDI prefix for player URLs
  * KCoreDirLister: reduce string allocations in `setNameFilter`
  * Strip trailing slash in iconForStandardPath
  * Allow to specify http1 only
  * CommandLauncherJob: clarify scope of responsibilities in documentation
  * kfileplacesmodeltest: fix `KFilePlacesModelTest::testReparse`
  * KFileItem: Use stat data for isDir if we already performed a stat
  * http: don't emit data({}) early
  * Worker template: bump min Qt/KF deps to match first official KF6 release
  * Worker template: add missing include
  * Don't leak existing file handles to newly spanwed KIO workers
  * update version for new release
* Wed Jan 31 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.249.0 (6.0 RC 2):
  * New bugfix release
  * For more details see https://kde.org/announcements/megarelease/6/rc2/
* Mon Jan 15 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.248.0 (6.0 RC 1)
  * For more details please see:
    https://kde.org/announcements/megarelease/6/rc1/
* Sat May 27 2023 Christophe Marin <christophe@krop.fr>
- Init kf6-kio
